/* --8<--8<--8<--8<--
 *
 * Copyright (C) 2006 Smithsonian Astrophysical Observatory
 *
 * This file is part of rbtree
 *
 * rbtree is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * rbtree is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * -->8-->8-->8-->8-- */

#include <string.h>

#include "rbtree.h"

/*

  A set of routines to compare user node data

  DESCRIPTION
    These routines compare user node data based upon assumptions about
    what the node's data pointer refers to.

  RETURNS
    returns an integer less than, equal to, or greater than zero if the
    first datum's field is respectively less than, equal to, or
    greater than the second datum's.

  AUTHOR
    Diab Jerius

*/


/*
   comparison based upon the arithmetic equality of the nodes' data pointers
*/

/*  */
int
rbtree_node_cmp_v(
  const void *dp1,		/* the first datum to compare */
  const void *dp2		/* the second datum to compare */
)
{
  /* do this carefully, treat 'em as unsigned quantities */
  if (dp1 > dp2)      return 1;
  else if (dp1 < dp2) return -1;
  return 0;
}


/*
   comparison assuming the nodes' data pointer points at strings
*/
int
rbtree_node_cmp_s(
  const void *dp1,		/* the first datum to compare */
  const void *dp2		/* the second datum to compare */
)
{
  return strcmp((char *) dp1, (char *) dp2);
}

